import os
import logging
import argparse

import numpy as np

import toolbox_scs as tb
import toolbox_scs.detectors as tbdet

logging.basicConfig(level=logging.INFO)
log_root = logging.getLogger(__name__)

# -----------------------------------------------------------------------------
# user input:
# -----------------------------------------------------------------------------
run_type = 'static, delay, .....'
description = 'useful description or comment .....'
#add xgm data to formatted file if save_xgm_binned was set to True
metadata = ['binner1', 'binner2', 'xgm_binned'] # ['binner1', 'binner2'] 
# -----------------------------------------------------------------------------


def formatting(run_number, run_folder):
    log_root.debug("Collect, combine and format files in run folder")

    run_formatted = tbdet.DSSCFormatter(run_folder)
    run_formatted.combine_files()

    run_formatted.add_dataArray(metadata)

    attrs = {'run_type':run_type,
             'description':description,
             'run_number':run_number}
    run_formatted.add_attributes(attrs)

    run_formatted.save_formatted_data(f'{run_folder}run_{run_number}_formatted.h5')
    log_root.debug("Formatting finished successfully.")


if __name__ == '__main__':
    parser = argparse.ArgumentParser()
    parser.add_argument('--run-number', metavar='S',
                        action='store',
                        help='run number')
    parser.add_argument('--run-folder', metavar='S',
                        action='store',
                        help='the run folder containing fractional data')
    args = parser.parse_args()

    formatting(str(args.run_number), str(args.run_folder))
